==> clickandpledge_connect-8.x-1.2002000101.tar.gz: clickandpledge_connect/src/Form/CnPAccountSettings.php <==
<?php

namespace Drupal\clickandpledge_connect\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Database\Connection;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * CONNECT platform account settings form.
 *
 * Uses to create a form, that verifies AccoundID and GUID with CONNECT
 * platform after verification, it stores the data with nickname in table.
 */
class CnPAccountSettings extends FormBase {

  /**
   * The Connection.
   *
   * @var mixed
   */
  protected $connection;

  /**
   * The Class Constructor.
   *
   * @param \Drupal\Core\Database\Connection $connection
   *   The database connection.
   */
  public function __construct(Connection $connection) {
    $this->connection = $connection;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('database')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'cnpc_account_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $displayForm = $this->displayAccountSettingsForm($form, $form_state);
    return $displayForm;
  }

  /**
   * Create a form to verify account details GUID and AccountID.
   *
   * @param array $form
   *   An associative array containing the structure of the form.
   * @param mixed $form_state
   *   The current state of the form.
   *
   * @return array
   *   Returns The form structure.
   */
  public function displayAccountSettingsForm(array $form, $form_state) {

    if (count($this->getRecords()) > 0) {
      $form['cnpc_menu'] = [
        '#prefix' => '<div class="cnp_heading"><ul>
                                        <li><a href="cnp_form_help">' . $this->t("Click & Pledge") . '</a></li>
                                        <li><a href="cnp_form">' . $this->t("Form Groups") . '</a></li>
        <li><a href="cnppledgetvchannels">pledgeTV <sup class="cnpc-regsymbol">&reg;</sup></a></li>
                                        <li><a class="cnpccurrent" href="cnp_formssettings">' . $this->t("Settings") . '</a></li>
                                        </ul>',
        '#suffix' => '</div>',
      ];
    }
    $form['cnpc_error_msg'] = [
      '#prefix' => '<div class="cnpc_error_msg" id="alertmsg">' . $this->t("Hi User!"),
      '#suffix' => '</div>',
    ];
    $form['cnpc_account_number'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Click & Pledge Account Number*'),
      '#description' => $this->t('Please enter the Account Number of your CONNECT Account<br>[CONNECT > Launcher > Settings > API Information > Account ID]<br><span class="cnpc_exists_error"></span>'),
      '#default_value' => '',
      '#attributes' => ['id' => 'cnpc_account_number'],
    ];
    $form['cnpc_account_guid'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Click & Pledge Account GUID*'),
      '#description' => $this->t('Please enter the Account <a href="https://support.clickandpledge.com/s/article/how-to-locate-account-id--api-account-guid" target="_blank">GUID</a> of your CONNECT Account<br>[CONNECT > Launcher > Settings > API Information > API (PaaS / FaaS): Account GUID].'),
      '#default_value' => '',
      '#attributes' => ['id' => 'cnpc_account_guid'],
    ];
    $form['base_url_cnpc'] = [
      '#type' => 'hidden',
      '#default_value' => base_path(),
      '#attributes' => ['id' => 'base_url_cnpc'],
    ];
    $form['nickname_cnpc'] = [
      '#type' => 'hidden',
      '#default_value' => '',
      '#attributes' => ['id' => 'nickname_cnpc'],
    ];
    $form['response_cnpc'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Nickname*'),
      '#default_value' => '',
      '#attributes' => [
        'id' => 'response_cnpc',
        'disabled' => 'disabled',
      ],
      '#prefix' => '<div class="nickname-div">',
      '#suffix' => '</div>',
    ];
    $form['save'] = [
      '#type' => 'submit',
      '#input' => TRUE,
      '#value' => $this->t('Verify'),
    ];
    $form['page_break'] = [
      '#prefix' => '<div class="page_break">',
      '#suffix' => '</div>',
    ];
    if (count($this->getRecords()) > 0) {
      $form['table_start'] = [
        '#prefix' => '<div class="tablelist">',
      ];
      $form['table_tag_start'] = [
        '#prefix' => "<div><table id='table_id' class='display'>
                            <thead>
                                <tr>
                                          <th>" . $this->t("Nickname") . "</th>
                                          <th>" . $this->t("Account Number") . "</th>
                                          <th>" . $this->t("GUID") . "</th>
                                          <th>" . $this->t("Created Date/Time") . "</th>
                                          <th>" . $this->t("Actions") . "</th>
                                </tr>
                            </thead>
                                  <tbody>",
      ];
      $datarec = $this->getRecords();
      $k = 1;
      foreach ($datarec as $rec) {
        $form['table_row' . $k] = [
          '#prefix' => '<tr>
                                    <td>' . $rec->cnpstngs_frndlyname . '</td>
                                    <td>' . $rec->cnpstngs_AccountNumber . '</td>
                                    <td>' . $rec->cnpstngs_guid . '</td>
                                    <td>' . date("F d, Y h:i a", strtotime($rec->cnpstngs_Date_Created)) . '</td>
                                    <td><a href="#" data-settid="' . $rec->cnpstngs_ID . '" data-settaccid="' . $rec->cnpstngs_AccountNumber . '" data-settguid=' . $rec->cnpstngs_guid . ' class="refreshAccounts" id="refreshacc_' . $rec->cnpstngs_ID . '" ><span class="refresh_icon"></span></a> &nbsp;|&nbsp; <a href="#" class="settingsDel" id="settingsDel" data-settrecid="' . $rec->cnpstngs_ID . '"><span class="bin_icon"></span></a></td>',
          '#suffix' => '</tr>',
        ];
        $k++;
      }
      $form['table_tag_end'] = [
        '#suffix' => '</tbody></table></div>',
      ];
      $form['table_end'] = [
        '#suffix' => '</div>',
      ];
    }
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $accNumber = ($form_state->getValue('cnpc_account_number')) ? $form_state->getValue('cnpc_account_number') : "";
    $accGuid = ($form_state->getValue('cnpc_account_guid')) ? $form_state->getValue('cnpc_account_guid') : "";
    $nickname = ($form_state->getValue('nickname_cnpc')) ? $form_state->getValue('nickname_cnpc') : "";
    $nickname = trim($nickname);
    $accNumber = trim($accNumber);
    $accGuid = trim($accGuid);
    $table_name = 'dp_cnpcsettingsdtl';
    $this->connection->insert($table_name)
      ->fields([
        'cnpstngs_frndlyname',
        'cnpstngs_AccountNumber',
        'cnpstngs_guid',
      ])
      ->values([
        $nickname,
        $accNumber,
        $accGuid,
      ])
      ->execute();
  }

  /**
   * Get all the account details.
   *
   * @return array
   *   Returns all account details as an array to display.
   */
  public function getRecords() {
    $prefix = $this->connection->tablePrefix();
    $table_name = $prefix . 'dp_cnpcsettingsdtl';
    $sql = "SELECT cnpstngs_ID,cnpstngs_frndlyname,cnpstngs_AccountNumber,cnpstngs_guid,cnpstngs_status,"
      . "cnpstngs_Date_Created,cnpstngs_Date_Modified FROM " . $table_name;
    $query = $this->connection->query($sql);
    return $query->fetchAll();
  }

}

==> clickandpledge_connect-8.x-1.2003000101.tar.gz: clickandpledge_connect/src/Form/CnPAccountSettings.php <==
<?php

namespace Drupal\clickandpledge_connect\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Database\Connection;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Url;
use Drupal\Core\Access\CsrfTokenGenerator;

/**
 * CONNECT platform account settings form.
 *
 * Uses to create a form, that verifies AccoundID and GUID with CONNECT
 * platform after verification, it stores the data with nickname in table.
 */
class CnPAccountSettings extends FormBase {

  /**
   * The Connection.
   *
   * @var mixed
   */
  protected $connection;

  /**
   * The CSRF token generator.
   *
   * @var \Drupal\Core\Access\CsrfTokenGenerator
   */
  protected $csrfToken;

  /**
   * The class constructor.
   *
   * @param \Drupal\Core\Database\Connection $connection
   *   The Database connection.
   * @param \Drupal\Core\Access\CsrfTokenGenerator $csrf_token
   *   The CSRF token generator.
   */
  public function __construct(Connection $connection, CsrfTokenGenerator $csrf_token) {
    $this->connection = $connection;
    $this->csrfToken = $csrf_token;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('database'), $container->get('csrf_token')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'cnpc_account_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $displayForm = $this->displayAccountSettingsForm($form, $form_state);
    return $displayForm;
  }

  /**
   * Create a form to verify account details GUID and AccountID.
   *
   * @param array $form
   *   An associative array containing the structure of the form.
   * @param mixed $form_state
   *   The current state of the form.
   *
   * @return array
   *   Returns The form structure.
   */
  public function displayAccountSettingsForm(array $form, $form_state) {

    if (count($this->getRecords()) > 0) {
      $form['cnpc_menu'] = [
        '#prefix' => '<div class="cnp_heading"><ul>
                                        <li><a href="cnp_form_help">' . $this->t("Click & Pledge") . '</a></li>
                                        <li><a href="cnp_form">' . $this->t("Form Groups") . '</a></li>
        <li><a href="cnppledgetvchannels">pledgeTV <sup class="cnpc-regsymbol">&reg;</sup></a></li>
                                        <li><a class="cnpccurrent" href="cnp_formssettings">' . $this->t("Settings") . '</a></li>
                                        </ul>',
        '#suffix' => '</div>',
      ];
    }
    if (isset($_REQUEST['msg']) && !empty($_REQUEST['msg'])) {
      if ($_REQUEST['msg'] === 'associated') {
        $form['cnpc_error_msg'] = [
          '#prefix' => '<div class="cnpc_error_msg cnpc_error" id="alertmsg">' . $this->t('This Account Number is associated with an existing form group. You must first delete the form group before deleting this account.'),
          '#suffix' => '</div>',
        ];
      }
      elseif ($_REQUEST['msg'] === 'error') {
        $form['cnpc_error_msg'] = [
          '#prefix' => '<div class="cnpc_error_msg cnpc_error" id="alertmsg">' . $this->t('Sorry Unable to delete settings account'),
          '#suffix' => '</div>',
        ];
      }
    }
    $form['cnpc_account_number'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Click & Pledge Account Number*'),
      '#description' => $this->t('Please enter the Account Number of your CONNECT Account<br>[CONNECT > Launcher > Settings > API Information > Account ID]<br><span class="cnpc_exists_error"></span>'),
      '#default_value' => '',
      '#attributes' => ['id' => 'cnpc_account_number'],
    ];
    $form['cnpc_account_guid'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Click & Pledge Account GUID*'),
      '#description' => $this->t('Please enter the Account <a href="https://support.clickandpledge.com/s/article/how-to-locate-account-id--api-account-guid" target="_blank">GUID</a> of your CONNECT Account<br>[CONNECT > Launcher > Settings > API Information > API (PaaS / FaaS): Account GUID].'),
      '#default_value' => '',
      '#attributes' => ['id' => 'cnpc_account_guid'],
    ];
    $form['base_url_cnpc'] = [
      '#type' => 'hidden',
      '#default_value' => base_path(),
      '#attributes' => ['id' => 'base_url_cnpc'],
    ];
    $form['nickname_cnpc'] = [
      '#type' => 'hidden',
      '#default_value' => '',
      '#attributes' => ['id' => 'nickname_cnpc'],
    ];
    $form['response_cnpc'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Nickname*'),
      '#default_value' => '',
      '#attributes' => [
        'id' => 'response_cnpc',
        'disabled' => 'disabled',
      ],
      '#prefix' => '<div class="nickname-div">',
      '#suffix' => '</div>',
    ];
    $form['save'] = [
      '#type' => 'submit',
      '#input' => TRUE,
      '#value' => $this->t('Verify'),
    ];
    $form['page_break'] = [
      '#prefix' => '<div class="page_break">',
      '#suffix' => '</div>',
    ];
    if (count($this->getRecords()) > 0) {
      $form['table_start'] = [
        '#prefix' => '<div class="tablelist">',
      ];
      $form['table_tag_start'] = [
        '#prefix' => "<div><table id='table_id' class='display'>
                            <thead>
                                <tr>
                                          <th>" . $this->t("Nickname") . "</th>
                                          <th>" . $this->t("Account Number") . "</th>
                                          <th>" . $this->t("GUID") . "</th>
                                          <th>" . $this->t("Created Date/Time") . "</th>
                                          <th>" . $this->t("Actions") . "</th>
                                </tr>
                            </thead>
                                  <tbody>",
      ];
      $datarec = $this->getRecords();
      $k = 1;
      foreach ($datarec as $rec) {
        $urlParams = ['variable' => $rec->cnpstngs_ID];
        $form['table_row' . $k] = [
          '#prefix' => '<tr>
                                    <td>' . $rec->cnpstngs_frndlyname . '</td>
                                    <td>' . $rec->cnpstngs_AccountNumber . '</td>
                                    <td>' . $rec->cnpstngs_guid . '</td>
                                    <td>' . date("F d, Y h:i a", strtotime($rec->cnpstngs_Date_Created)) . '</td>
                                    <td><a href="#" data-settid="' . $rec->cnpstngs_ID . '" data-settaccid="' . $rec->cnpstngs_AccountNumber . '" data-settguid=' . $rec->cnpstngs_guid . ' class="refreshAccounts" id="refreshacc_' . $rec->cnpstngs_ID . '" ><span class="refresh_icon"></span></a> &nbsp;|&nbsp; <a href="' . $this->cnpGenerateTokenUrl('cnpconnect.cnpc_deletesettings_details', $urlParams) . '" class="settingsDel" id="settingsDel" data-settrecid="' . $rec->cnpstngs_ID . '"><span class="bin_icon"></span></a></td>',
          '#suffix' => '</tr>',
        ];
        $k++;
      }
      $form['table_tag_end'] = [
        '#suffix' => '</tbody></table></div>',
      ];
      $form['table_end'] = [
        '#suffix' => '</div>',
      ];
    }
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $accNumber = ($form_state->getValue('cnpc_account_number')) ? $form_state->getValue('cnpc_account_number') : "";
    $accGuid = ($form_state->getValue('cnpc_account_guid')) ? $form_state->getValue('cnpc_account_guid') : "";
    $nickname = ($form_state->getValue('nickname_cnpc')) ? $form_state->getValue('nickname_cnpc') : "";
    $nickname = trim($nickname);
    $accNumber = trim($accNumber);
    $accGuid = trim($accGuid);
    $table_name = 'dp_cnpcsettingsdtl';
    $this->connection->insert($table_name)
      ->fields([
        'cnpstngs_frndlyname',
        'cnpstngs_AccountNumber',
        'cnpstngs_guid',
      ])
      ->values([
        $nickname,
        $accNumber,
        $accGuid,
      ])
      ->execute();
  }

  /**
   * Get all the account details.
   *
   * @return array
   *   Returns all account details as an array to display.
   */
  public function getRecords() {
    $prefix = $this->connection->tablePrefix();
    $table_name = $prefix . 'dp_cnpcsettingsdtl';
    $sql = "SELECT cnpstngs_ID,cnpstngs_frndlyname,cnpstngs_AccountNumber,cnpstngs_guid,cnpstngs_status,"
      . "cnpstngs_Date_Created,cnpstngs_Date_Modified FROM " . $table_name;
    $query = $this->connection->query($sql);
    return $query->fetchAll();
  }

  /**
   * Creates an URL string with a token by appending in query string.
   *
   * @param mixed $routeName
   *   Name of the route to generate the URL.
   * @param mixed $urlParams
   *   Contains URL parameters as an array.
   *
   * @return mixed
   *   Return an absolute URL with token
   */
  public function cnpGenerateTokenUrl($routeName, $urlParams) {
    $url = Url::fromRoute($routeName, $urlParams);
    $token = $this->csrfToken->get($url->getInternalPath());
    $url->setOptions(['absolute' => TRUE, 'query' => ['token' => $token]]);
    return $url->toString();
  }

}
